Learn R Programming

spagmix (version 0.3-5)

unify.owin: Spatial window unit rescaler

Description

Rescales any owin to fall inside the unit square.

Usage

unify.owin(W)

Arguments

W

An object of class owin giving the spatial window to be transformed.

Value

The rescaled owin.

Details

This function is a simple wrapper for affine deployed to rescale a supplied owin to fall inside the unit square.

Examples

Run this code
# NOT RUN {
W <- Window(chorley)
U <- unify.owin(W)

par(mfrow=c(1,2))
plot(W,axes=TRUE)
plot(U,axes=TRUE)
# }

Run the code above in your browser using DataLab