powered by
Rescales any owin to fall inside the unit square.
owin
unify.owin(W)
An object of class owin giving the spatial window to be transformed.
The rescaled owin.
This function is a simple wrapper for affine deployed to rescale a supplied owin to fall inside the unit square.
affine
# NOT RUN { W <- Window(chorley) U <- unify.owin(W) par(mfrow=c(1,2)) plot(W,axes=TRUE) plot(U,axes=TRUE) # }
Run the code above in your browser using DataLab